@@ -3,12 +3,18 @@ import numpy as np
 
 from zebrazoom.code.getImage.getForegroundImageSequential import getForegroundImageSequential
 from zebrazoom.code.getImage.getForegroundImage import getForegroundImage
+from zebrazoom.code.getImage.getImageSequential import getImageSequential
+from zebrazoom.code.getImage.getImage import getImage
 from zebrazoom.code.getImage.headEmbededFrame import headEmbededFrame
 from zebrazoom.code.getImage.headEmbededFrameSequential import headEmbededFrameSequential
 from zebrazoom.code.getImage.headEmbededFrameSequentialBackExtract import headEmbededFrameSequentialBackExtract
 from zebrazoom.code.getImage.headEmbededFrameBackExtract import headEmbededFrameBackExtract
 
 def getImages(hyperparameters, cap, videoPath, i, background, wellNumber, wellPositions):
+  
+  initialCurFrame = 0
+  back = 0
+
   if hyperparameters["headEmbeded"]:
     if hyperparameters["headEmbededRemoveBack"] == 0:
       if hyperparameters["adjustHeadEmbededTracking"] == 0:
@@ -24,9 +30,16 @@ def getImages(hyperparameters, cap, videoPath, i, background, wellNumber, wellPo
       gray = frame.copy()
   else:
     if hyperparameters["adjustFreelySwimTracking"] == 0:
-      frame = getForegroundImageSequential(cap, videoPath, background, i, wellNumber, wellPositions, hyperparameters)
+      if len(background):
+        [frame, initialCurFrame, back] = getForegroundImageSequential(cap, videoPath, background, i, wellNumber, wellPositions, hyperparameters)
+      else:
+        frame = getImageSequential(cap, videoPath, i, wellNumber, wellPositions, hyperparameters)
     else:
-      frame = getForegroundImage(videoPath, background, i, wellNumber, wellPositions, hyperparameters)
+      if len(background):
+        [frame, initialCurFrame, back] = getForegroundImage(videoPath, background, i, wellNumber, wellPositions, hyperparameters)
+      else:
+        frame = getImage(videoPath, i, wellNumber, wellPositions, hyperparameters)
+    
     gray = frame.copy()
     
     ret,thresh1 = cv2.threshold(gray,hyperparameters["thresholdForBlobImg"],255,cv2.THRESH_BINARY)
@@ -74,4 +87,4 @@ def getImages(hyperparameters, cap, videoPath, i, background, wellNumber, wellPo
   thresh2 = thresh1.copy()
   thresh2 = cv2.dilate(thresh2, kernel, iterations=hyperparameters["dilateIter"])
   
-  return [frame, gray, thresh1, blur, thresh2, frame2]
+  return [frame, gray, thresh1, blur, thresh2, frame2, initialCurFrame, back]
